==> haskell-blaze-html-0.8.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-html/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.8.1.1
id: blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
key: blaze_Iq6GES6DAMS0745KzFL7i6
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-html-0.8.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-html-0.8.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-html-0.8.1.1
hs-libraries: HSblaze-html-0.8.1.1-Iq6GES6DAMS0745KzFL7i6
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.8.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-html/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.8.1.1
id: blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
key: blaze_1fCoF4onMJE2jDLBViwynk
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-html-0.8.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-html-0.8.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-html-0.8.1.1
hs-libraries: HSblaze-html-0.8.1.1-1fCoF4onMJE2jDLBViwynk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
